@@ -1,7 +1,3 @@
-import pandas as pd
-import numpy as np
-import os
-
 
 def Gene2Entrez():
     DAVID_Entrez = pd.read_csv('ENTREZ_GENE_ID2DAVID_GENE_NAME.txt',sep = '\t',header = None)
